@@ -1,4 +1,4 @@
-from microservice_template_core.tools.db import db
+# from microservice_template_core.tools.db import db
 from microservice_template_core.tools.prometheus_metrics import Prom
 from microservice_template_core.tools.logger import logger
 from microservice_template_core.core import Core
