@@ -15,8 +15,8 @@ class Core:
         self.register_namespaces()
         self.app = self.create_flask_app()
         self.ma = None
-        if DbConfig.USE_DB:
-            self.connect_db()
+        # if DbConfig.USE_DB:
+        #     self.connect_db()
         if FlaskConfig.FLASK_JWT:
             self.add_authorization()
 
@@ -38,11 +38,11 @@ class Core:
         for namespace in default_namespaces + self.namespaces:
             api.add_namespace(namespace)
 
-    def connect_db(self):
-        from microservice_template_core.tools.db import db
-        db.init_app(self.app)
-        db.app = self.app
-        db.create_all()
+    # def connect_db(self):
+    #     from microservice_template_core.tools.db import db
+    #     db.init_app(self.app)
+    #     db.app = self.app
+    #     db.create_all()
 
     def add_authorization(self):
         from flask_jwt_extended import JWTManager
