@@ -21,6 +21,10 @@ class KafkaConsumeMessages(object):
                 'bootstrap.servers': KafkaConfig.KAFKA_SERVERS,
                 'group.id': ServiceConfig.SERVICE_NAME,
                 'auto.offset.reset': 'latest',
+                'allow.auto.create.topics': True,
+                'session.timeout.ms': KafkaConfig.consumer_session_timeout_ms,
+                'heartbeat.interval.ms': KafkaConfig.consumer_heartbeat_interval_ms,
+                'offset.store.method': 'broker'
             }
         )
 
